@@ -36,6 +36,7 @@ static gchar *contributors[] = {
 	"J\xc3\xa9r\xc3\xb4me Bolliet",
 	"Andreas Bolsch",
 	"Dave Bordoley",
+	"Karsten Br\xC3\xA4" "ckelmann",
 	"Dario Bressanini",
 	"Emmanuel Briot",
 	"Stephen Browne",
@@ -147,6 +148,7 @@ static gchar *contributors[] = {
 	"Michael Kellen",
 	"Stephen Kiernan",
 	"Spencer Kimball",
+	"Christian Kirbach",
 	"Alexander Kirillov",
 	"Peter Kirchgessner",
 	"Helmut K\xc3\xb6" "berle",
@@ -237,6 +239,7 @@ static gchar *contributors[] = {
 	"Cameron Parish",
 	"Conrad Parker",
 	"Stuart Parmenter",
+	"Guilherme de S. Pastore",
 	/* Danilo Segan */
 	"'\xd0\x94\xd0\xb0\xd0\xbd\xd0\xb8\xd0\xbb\xd0\xbe\x20\xd0\xa8\xd0\xb5\xd0\xb3\xd0\xb0\xd0\xbd",
 	"Nils Pedersen",
@@ -255,6 +258,7 @@ static gchar *contributors[] = {
 	"Tero Pulkkinen",
 	"The Rasterman",
 	"Oliver Rauch",
+	"Lucas Almeida Rocha",
 	"Christian Rose",
 	"Cody Russell",
 	"Reklaw",
@@ -325,6 +329,7 @@ static gchar *contributors[] = {
 	"Vendu",
 	"Andrew Veliath",
 	"Luis Villa",
+	"Olav Vitters",
 	"Marius Vollmer",
 	"Shawn Wagner",
 	N_("Wanda The GNOME Fish"),
